# This file was auto-generated by Fern from our API Definition.

import typing
from ..core.client_wrapper import SyncClientWrapper
from .raw_client import RawTrainingClient
from ..core.request_options import RequestOptions
from ..types.training_config import TrainingConfig
from ..types.model_status import ModelStatus
from ..core.client_wrapper import AsyncClientWrapper
from .raw_client import AsyncRawTrainingClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class TrainingClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawTrainingClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawTrainingClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawTrainingClient
        """
        return self._raw_client

    def get_models(self, *, request_options: typing.Optional[RequestOptions] = None) -> TrainingConfig:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TrainingConfig
            Successful Response

        Examples
        --------
        from phospho import PhosphoApi

        client = PhosphoApi(
            base_url="https://yourhost.com/path/to/api",
        )
        client.training.get_models()
        """
        response = self._raw_client.get_models(
            request_options=request_options,
        )
        return response.data

    def add_model_to_training_list(
        self,
        *,
        creation_date: str,
        dataset_name: str,
        model_name: str,
        model_type: str,
        url: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> TrainingConfig:
        """
        Add a model to the training list

        Parameters
        ----------
        creation_date : str

        dataset_name : str

        model_name : str

        model_type : str

        url : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TrainingConfig
            Successful Response

        Examples
        --------
        from phospho import PhosphoApi

        client = PhosphoApi(
            base_url="https://yourhost.com/path/to/api",
        )
        client.training.add_model_to_training_list(
            creation_date="creation_date",
            dataset_name="dataset_name",
            model_name="model_name",
            model_type="model_type",
            url="url",
        )
        """
        response = self._raw_client.add_model_to_training_list(
            creation_date=creation_date,
            dataset_name=dataset_name,
            model_name=model_name,
            model_type=model_type,
            url=url,
            request_options=request_options,
        )
        return response.data

    def delete_model_from_training_list(
        self,
        *,
        creation_date: str,
        dataset_name: str,
        model_name: str,
        model_type: str,
        url: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> TrainingConfig:
        """
        Delete a model from the training list

        Parameters
        ----------
        creation_date : str

        dataset_name : str

        model_name : str

        model_type : str

        url : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TrainingConfig
            Successful Response

        Examples
        --------
        from phospho import PhosphoApi

        client = PhosphoApi(
            base_url="https://yourhost.com/path/to/api",
        )
        client.training.delete_model_from_training_list(
            creation_date="creation_date",
            dataset_name="dataset_name",
            model_name="model_name",
            model_type="model_type",
            url="url",
        )
        """
        response = self._raw_client.delete_model_from_training_list(
            creation_date=creation_date,
            dataset_name=dataset_name,
            model_name=model_name,
            model_type=model_type,
            url=url,
            request_options=request_options,
        )
        return response.data

    def update_model_status(
        self, *, model_url: str, request_options: typing.Optional[RequestOptions] = None
    ) -> ModelStatus:
        """
        Fetch the status of a model

        Parameters
        ----------
        model_url : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ModelStatus
            Successful Response

        Examples
        --------
        from phospho import PhosphoApi

        client = PhosphoApi(
            base_url="https://yourhost.com/path/to/api",
        )
        client.training.update_model_status(
            model_url="model_url",
        )
        """
        response = self._raw_client.update_model_status(
            model_url=model_url,
            request_options=request_options,
        )
        return response.data


class AsyncTrainingClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawTrainingClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawTrainingClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawTrainingClient
        """
        return self._raw_client

    async def get_models(self, *, request_options: typing.Optional[RequestOptions] = None) -> TrainingConfig:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TrainingConfig
            Successful Response

        Examples
        --------
        import asyncio

        from phospho import AsyncPhosphoApi

        client = AsyncPhosphoApi(
            base_url="https://yourhost.com/path/to/api",
        )


        async def main() -> None:
            await client.training.get_models()


        asyncio.run(main())
        """
        response = await self._raw_client.get_models(
            request_options=request_options,
        )
        return response.data

    async def add_model_to_training_list(
        self,
        *,
        creation_date: str,
        dataset_name: str,
        model_name: str,
        model_type: str,
        url: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> TrainingConfig:
        """
        Add a model to the training list

        Parameters
        ----------
        creation_date : str

        dataset_name : str

        model_name : str

        model_type : str

        url : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TrainingConfig
            Successful Response

        Examples
        --------
        import asyncio

        from phospho import AsyncPhosphoApi

        client = AsyncPhosphoApi(
            base_url="https://yourhost.com/path/to/api",
        )


        async def main() -> None:
            await client.training.add_model_to_training_list(
                creation_date="creation_date",
                dataset_name="dataset_name",
                model_name="model_name",
                model_type="model_type",
                url="url",
            )


        asyncio.run(main())
        """
        response = await self._raw_client.add_model_to_training_list(
            creation_date=creation_date,
            dataset_name=dataset_name,
            model_name=model_name,
            model_type=model_type,
            url=url,
            request_options=request_options,
        )
        return response.data

    async def delete_model_from_training_list(
        self,
        *,
        creation_date: str,
        dataset_name: str,
        model_name: str,
        model_type: str,
        url: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> TrainingConfig:
        """
        Delete a model from the training list

        Parameters
        ----------
        creation_date : str

        dataset_name : str

        model_name : str

        model_type : str

        url : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        TrainingConfig
            Successful Response

        Examples
        --------
        import asyncio

        from phospho import AsyncPhosphoApi

        client = AsyncPhosphoApi(
            base_url="https://yourhost.com/path/to/api",
        )


        async def main() -> None:
            await client.training.delete_model_from_training_list(
                creation_date="creation_date",
                dataset_name="dataset_name",
                model_name="model_name",
                model_type="model_type",
                url="url",
            )


        asyncio.run(main())
        """
        response = await self._raw_client.delete_model_from_training_list(
            creation_date=creation_date,
            dataset_name=dataset_name,
            model_name=model_name,
            model_type=model_type,
            url=url,
            request_options=request_options,
        )
        return response.data

    async def update_model_status(
        self, *, model_url: str, request_options: typing.Optional[RequestOptions] = None
    ) -> ModelStatus:
        """
        Fetch the status of a model

        Parameters
        ----------
        model_url : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ModelStatus
            Successful Response

        Examples
        --------
        import asyncio

        from phospho import AsyncPhosphoApi

        client = AsyncPhosphoApi(
            base_url="https://yourhost.com/path/to/api",
        )


        async def main() -> None:
            await client.training.update_model_status(
                model_url="model_url",
            )


        asyncio.run(main())
        """
        response = await self._raw_client.update_model_status(
            model_url=model_url,
            request_options=request_options,
        )
        return response.data
