# This file was auto-generated by Fern from our API Definition.

import typing
from ..core.client_wrapper import SyncClientWrapper
from ..core.request_options import RequestOptions
from ..core.http_response import HttpResponse
from ..types.training_config import TrainingConfig
from ..core.pydantic_utilities import parse_obj_as
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.http_validation_error import HttpValidationError
from ..types.model_status import ModelStatus
from ..core.client_wrapper import AsyncClientWrapper
from ..core.http_response import AsyncHttpResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawTrainingClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def get_models(self, *, request_options: typing.Optional[RequestOptions] = None) -> HttpResponse[TrainingConfig]:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[TrainingConfig]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "training/models",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    TrainingConfig,
                    parse_obj_as(
                        type_=TrainingConfig,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def add_model_to_training_list(
        self,
        *,
        creation_date: str,
        dataset_name: str,
        model_name: str,
        model_type: str,
        url: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[TrainingConfig]:
        """
        Add a model to the training list

        Parameters
        ----------
        creation_date : str

        dataset_name : str

        model_name : str

        model_type : str

        url : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[TrainingConfig]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "training/models",
            method="POST",
            json={
                "creation_date": creation_date,
                "dataset_name": dataset_name,
                "model_name": model_name,
                "model_type": model_type,
                "url": url,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    TrainingConfig,
                    parse_obj_as(
                        type_=TrainingConfig,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def delete_model_from_training_list(
        self,
        *,
        creation_date: str,
        dataset_name: str,
        model_name: str,
        model_type: str,
        url: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[TrainingConfig]:
        """
        Delete a model from the training list

        Parameters
        ----------
        creation_date : str

        dataset_name : str

        model_name : str

        model_type : str

        url : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[TrainingConfig]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "training/models/delete",
            method="POST",
            json={
                "creation_date": creation_date,
                "dataset_name": dataset_name,
                "model_name": model_name,
                "model_type": model_type,
                "url": url,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    TrainingConfig,
                    parse_obj_as(
                        type_=TrainingConfig,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def update_model_status(
        self, *, model_url: str, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[ModelStatus]:
        """
        Fetch the status of a model

        Parameters
        ----------
        model_url : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[ModelStatus]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            "training/models/status",
            method="POST",
            json={
                "model_url": model_url,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ModelStatus,
                    parse_obj_as(
                        type_=ModelStatus,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncRawTrainingClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def get_models(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[TrainingConfig]:
        """
        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[TrainingConfig]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "training/models",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    TrainingConfig,
                    parse_obj_as(
                        type_=TrainingConfig,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def add_model_to_training_list(
        self,
        *,
        creation_date: str,
        dataset_name: str,
        model_name: str,
        model_type: str,
        url: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[TrainingConfig]:
        """
        Add a model to the training list

        Parameters
        ----------
        creation_date : str

        dataset_name : str

        model_name : str

        model_type : str

        url : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[TrainingConfig]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "training/models",
            method="POST",
            json={
                "creation_date": creation_date,
                "dataset_name": dataset_name,
                "model_name": model_name,
                "model_type": model_type,
                "url": url,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    TrainingConfig,
                    parse_obj_as(
                        type_=TrainingConfig,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def delete_model_from_training_list(
        self,
        *,
        creation_date: str,
        dataset_name: str,
        model_name: str,
        model_type: str,
        url: str,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[TrainingConfig]:
        """
        Delete a model from the training list

        Parameters
        ----------
        creation_date : str

        dataset_name : str

        model_name : str

        model_type : str

        url : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[TrainingConfig]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "training/models/delete",
            method="POST",
            json={
                "creation_date": creation_date,
                "dataset_name": dataset_name,
                "model_name": model_name,
                "model_type": model_type,
                "url": url,
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    TrainingConfig,
                    parse_obj_as(
                        type_=TrainingConfig,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def update_model_status(
        self, *, model_url: str, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[ModelStatus]:
        """
        Fetch the status of a model

        Parameters
        ----------
        model_url : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[ModelStatus]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            "training/models/status",
            method="POST",
            json={
                "model_url": model_url,
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    ModelStatus,
                    parse_obj_as(
                        type_=ModelStatus,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    typing.cast(
                        HttpValidationError,
                        parse_obj_as(
                            type_=HttpValidationError,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)
